Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(22)

Unified Diff: pkg/analyzer/lib/src/task/model.dart

Issue 1012993002: Rename ContributionPoint and error result (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analyzer/lib/src/task/dart.dart ('k') | pkg/analyzer/lib/task/dart.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/task/model.dart
diff --git a/pkg/analyzer/lib/src/task/model.dart b/pkg/analyzer/lib/src/task/model.dart
index 05a922baae41fff0389ec375cc74d6241cc22767..787dac47ec7426bb62fa9daa20a8f42813afa151 100644
--- a/pkg/analyzer/lib/src/task/model.dart
+++ b/pkg/analyzer/lib/src/task/model.dart
@@ -9,19 +9,19 @@ import 'package:analyzer/src/task/inputs.dart';
import 'package:analyzer/task/model.dart';
/**
- * A concrete implementation of a [ContributionPoint].
+ * A concrete implementation of a [CompositeResultDescriptor].
*/
-class ContributionPointImpl<V> extends ResultDescriptorImpl<V>
- implements ContributionPoint<V> {
+class CompositeResultDescriptorImpl<V> extends ResultDescriptorImpl<V>
+ implements CompositeResultDescriptor<V> {
/**
* The results that contribute to this result.
*/
final List<ResultDescriptor<V>> contributors = <ResultDescriptor<V>>[];
/**
* Initialize a newly created contribution point to have the given [name].
*/
- ContributionPointImpl(String name) : super(name, null);
+ CompositeResultDescriptorImpl(String name) : super(name, null);
/**
* Record that the given analysis [result] contibutes to this result.
@@ -47,12 +47,12 @@ class ResultDescriptorImpl<V> implements ResultDescriptor<V> {
/**
* Initialize a newly created analysis result to have the given [name] and
* [defaultValue]. If a contribution point is specified, then this result will
* contribute to it.
*/
ResultDescriptorImpl(this.name, this.defaultValue,
- {ContributionPoint contributesTo}) {
- if (contributesTo is ContributionPointImpl) {
+ {CompositeResultDescriptor contributesTo}) {
scheglov 2015/03/16 21:48:59 Do we want to use a different name?
Brian Wilkerson 2015/03/17 14:52:20 I thought about it, but I think that the individua
+ if (contributesTo is CompositeResultDescriptorImpl) {
contributesTo.recordContributor(this);
}
}
@@ -9,19 +9,19 @@ import 'package:analyzer/src/task/inputs.dart';
final List<ResultDescriptor<V>> contributors = <ResultDescriptor<V>>[];
/**
- * Initialize a newly created contribution point to have the given [name].
+ * Initialize a newly created composite result to have the given [name].
*/
@@ -47,12 +47,12 @@ class ResultDescriptorImpl<V> implements ResultDescriptor<V> {
/**
* Initialize a newly created analysis result to have the given [name] and
- * [defaultValue]. If a contribution point is specified, then this result will
+ * [defaultValue]. If a composite result is specified, then this result will
* contribute to it.
*/
« no previous file with comments | « pkg/analyzer/lib/src/task/dart.dart ('k') | pkg/analyzer/lib/task/dart.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698